Learn R Programming

rCGH (version 1.0.0)

byGeneTable: Converting a Segmentation Table Into a By-Gene Table

Description

This function creates a by-gene table by listing all the genes contained in each of the segments in the segmentation table. Gene annotations (symbol, location,...), segmented Log2Ratios, and segment legnth are reported in the final table. A supplementary score is the relativeLog: the magnitude, in Log2, from the closest centromere.

Usage

byGeneTable(segTable, symbol = NULL, verbose = TRUE)

Arguments

segTable
: data frame. A segmentation table exported from an object of class "rCGH"
symbol
: character. A valid HUGO symbol. When NULL the full gene table is returned, the corresponding gene information only o/w.
verbose
: logical. When TRUE progress is printed.

Value

An object of class "rCGH"

Details

For gene annotations, Hg19/GRCh37 annotations downloaded from NCBI are considered.

See Also

getSegTable

Examples

Run this code

filePath <- system.file("extdata", "Affy_cytoScan.cyhd.CN5.CNCHP.txt.bz2",
    package = "rCGH")
cgh <- readAffyCytoScan(filePath, sampleName = "AffyScHD")
cgh <- adjustSignal(cgh, nCores=1)
cgh <- EMnormalize(cgh)
cgh <- segmentCGH(cgh, nCores=1)
st <- getSegTable(cgh)
bygene <- byGeneTable(st)
head(bygene)

Run the code above in your browser using DataLab