Learn R Programming

rCGH (version 1.2.0)

multiplot: Static Genomic Profile and LOH Visualization

Description

This function display a static view of the genomic profile and the allelic difference stored in an object of class "rCGH". If no allelic difference is available, the genomic profile only is displayed.

Usage

"multiplot"(object, symbol=NULL, gain=.5, loss=(-.5), minLen=10, pCol = "grey50", GLcol = c("blue", "red3"), L=matrix(seq(1, 12)), p=c(2/3, 1/3), Title=NULL, ylim=NULL)

Arguments

object
: An object of class "rCGH"
symbol
: character. A valid HUGO symbol (case insensitive).
gain
: numeric. A gain threshold value (in $Log2(Ratio)$) from where gained segments will be shown, in blue.
loss
: numeric. A loss threshold value (in $Log2(Ratio)$) from where lossed segments will be shown, in red.
minLen
: numeric. The mininal length for a segment, in Kb. When NULL (default), segments are reported as they have been computed with segmentCGH, segments shorter than the specified value are re-merged otherwise.
pCol
: string. The probe points color. DEfault is "grey50".
GLcol
: vector. A vector of 2 colors: the gained and lost segments colors, respectively. Default is "blue" for gains and "red3" for losses.
L
: matrix. A matrix defining how the layout is built. Default is 12 lines.
p
: numeric. The proportion of each plot in the plot window. Default is 2/3, 1/3, which corresponds to 8 and 4 lines for the genomic profile and the LOH plot, respectiviely.
Title
: character string. A title for the density plot. If NULL (default), the sample name (when exists) will be used.
ylim
: numeric. A vector of two values specifying the y-axis range. See plotProfile.

Value

None.

See Also

plotDensity, plotProfile, plotLOH, view

Examples

Run this code

filePath <- system.file("extdata", "Affy_cytoScan.cyhd.CN5.CNCHP.txt.bz2",
    package = "rCGH")
cgh <- readAffyCytoScan(filePath, sampleName = "AffyScHD")
cgh <- adjustSignal(cgh, nCores=1)
cgh <- EMnormalize(cgh)
cgh <- segmentCGH(cgh, nCores=1)

# Static visalizations
multiplot(cgh, "erbb2")

Run the code above in your browser using DataLab