Learn R Programming

rCGH (version 1.0.0)

rCGH-package: Comprehensive Pipeline for Analyzing and Visualizing Agilent and Affymetrix Array-Based CGH Data

Description

A comprehensive pipeline for analyzing and interactively visualizing genomic profiles generated through Agilent and Affymetrix microarrays. As inputs, rCGH supports Agilent dual-color Feature Extraction files (.txt), from 44 to 400K, and Affymetrix SNP6.0 and cytoScan probeset.txt, cychp.txt, and cnchp.txt files, exported from ChAS or Affymetrix Power Tools. This package takes over all the steps required for a genomic profile analysis, from reading the files to the segmentation and genes annotations, and provides several visualization functions (static or interactive) which facilitate profiles interpretation. Input files can be in compressed format, e.g. .bz2 or .gz.

Arguments

See Also

readAgilent, readAffySNP6, readAffyCytoScan

Examples

Run this code

filePath <- system.file("extdata", "Affy_cytoScan.cyhd.CN5.CNCHP.txt.bz2",
    package = "rCGH")
object1 <- readAffyCytoScan(filePath, sampleName = "AffyScHD")

object2 <- adjustSignal(object1, nCores=1)
object3 <- EMnormalize(object2)
object4 <- segmentCGH(object3, nCores=1)

# Static visalizations
plotDensity(object4)
multiplot(object4)

## Not run: 
# # Interactive visalizations
# view(object4)
# ## End(Not run)

Run the code above in your browser using DataLab